@@ -18,6 +18,12 @@ MainWindow::MainWindow(QWidget *parent) :
     connectButtons();
     MainWindow::kernelcheck();
     QMainWindow::setCentralWidget(ui->verticalLayoutWidget);
+    if(!QFile::exists("/proc/driver/musb_hdrc")) {
+        QMessageBox::critical(this, tr("Fatal Error"),
+                              tr("h-e-n is running on a device that doesn't have the musb OTG driver!"));
+        QApplication::exit(1);
+        QMainWindow::close();
+    }
 }
 
 MainWindow::~MainWindow()
@@ -32,8 +38,6 @@ MainWindow::~MainWindow()
         //system("mv /opt/h-e-n/status-area-applet-battery.desktop /usr/share/applications/hildon-status-menu/ && killall hildon-status-menu");
         system("start bme &");
 #endif
-    delete ui;
-    system("rm -f /var/tmp/.kernelversion 2> /dev/null");
 }
 
 // About dialog.
@@ -49,7 +53,7 @@ void MainWindow::connectButtons()
     connect(ui->actionAbout, SIGNAL(triggered()), this, SLOT(about()));
     connect(ui->actionAbout_Qt, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
     connect(ui->actionKernel_messages, SIGNAL(triggered()), this, SLOT(kernelmessages())); // kernel messages menu item
-    //connect(ui->actionSettings, SIGNAL(triggered()), this, SLOT(settingsWindow()));
+    connect(ui->actionSettings1, SIGNAL(triggered()), this, SLOT(settingsDialog()));
     // Buttons in app.
     connect(ui->FShostmode, SIGNAL(clicked()), this, SLOT(hostmodeFS()));
     connect(ui->HShostmode, SIGNAL(clicked()), this, SLOT(hostmodeHS()));
@@ -101,7 +105,15 @@ void MainWindow::vbusOff()
 void MainWindow::mount()
 {
 #ifdef Q_WS_MAEMO_5
-    system("/opt/h-e-n/mount.sh --mount");
+    if(QSettings().value("mount/openfilemanager").toString() == "true")
+    {
+        if(QSettings().value("mount/filemanager").toString() == "filebox")
+            system("/opt/h-e-n/mount.sh --mount --openfilemanager --filebox");
+        if(QSettings().value("mount/filemanager").toString() == "osso-filemanager")
+            system("/opt/h-e-n/mount.sh --mount --openfilemanager --osso-filemanager");
+    } else {
+        system("/opt/h-e-n/mount.sh --mount");
+    }
 #endif
     ui->unmountButton->show();
 }
@@ -156,7 +168,10 @@ void MainWindow::kernelcheck()
                     else
                         statusBar()->showMessage(tr("ERROR! Current kernel version: ") + osreleaseversion);
                     ui->labelUnsupportedKernel->show();
+                    osrelease.close();
                 }
+    if(QFile::exists("/var/tmp/.hostmodeversion"))
+        QFile::remove("/var/tmp/.hostmodeversion");
 }
 
 void MainWindow::overrideKernelVersion()
@@ -239,12 +254,11 @@ void MainWindow::helpWindow()
     myHelpWindow->show();
 }
 
-/*void MainWindow::settingsWindow()
+void MainWindow::settingsDialog()
 {
-    setWindowFlags(windowFlags() | Qt::Window);
-    SettingsWindow *mySettingsWindow = new SettingsWindow(this);
-    mySettingsWindow->show();
-}*/
+    SettingsDialog *mySettingsDialog = new SettingsDialog(this);
+    mySettingsDialog->show();
+}
 
 void MainWindow::orientationChanged()
 {
